﻿using Janus.Core.Models;
using Janus.Core.Models.Results;
using System;
using System.Collections.Generic;
using System.Text;

namespace Janus.Core.Interfaces
{
    /// <summary>
    /// Interface for the analyzers.
    /// Should be generic for all analyzers.
    /// </summary>
    public interface IAnalyzer
    {
        /// <summary>
        /// Performs analysis on the whole solution.
        /// </summary>
        /// <param name="solutionToAnalyze">Solution to analyze</param>
        /// <returns>Analysis result</returns>
        public AnalysisResult AnalyzeSolution(SolutionItem solutionToAnalyze);

        /// <summary>
        /// Performs analysis on the list of the solutions.
        /// </summary>
        /// <param name="solutionsToAnalyze">Solutions to analyze</param>
        /// <returns>Analysis result</returns>
        public AnalysisResult AnalyzeSolutions(List<SolutionItem> solutionsToAnalyze);

        /// <summary>
        /// Performs analysis on the single project.
        /// </summary>
        /// <param name="projectToAnalyze">Project to analyze</param>
        /// <returns>Analysis result</returns>
        public AnalysisResult AnalyzeProject(ProjectItem projectToAnalyze);

        /// <summary>
        /// Performs analysis on the list of the projects.
        /// </summary>
        /// <param name="projectsToAnalyze">Projects to analyze</param>
        /// <returns>Analysis result</returns>
        public AnalysisResult AnalyzeProjects(List<ProjectItem> projectsToAnalyze);

        /// <summary>
        /// Performs analysis on the list of the dependency.
        /// </summary>
        /// <param name="dependencyToAnalyze">Dependency to analyze</param>
        /// <returns>Analysis result</returns>
        public AnalysisResult AnalyzeDependency(DependencyItem dependencyToAnalyze);

        /// <summary>
        /// Performs analysis on the list of given dependencies.
        /// </summary>
        /// <param name="dependenciesToAnalyze">List of dependencies to analyze</param>
        /// <returns>Analysis result</returns>
        public AnalysisResult AnalyzeDependencies(List<DependencyItem> dependenciesToAnalyze);

    }
}
