﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Janus.Core.Models
{
    /// <summary>
    /// This class is container for all the annotation information added by analyzers.
    /// </summary>
    public class AnnotationInfoItem
    {
        /// <summary>
        /// This is enum for the information level provided by the annotation info
        /// </summary>
        public enum InformationLevel
        {
            /// <summary>
            /// Basic information
            /// </summary>
            Info, 

            /// <summary>
            /// Warning, this is something which should be highlighted
            /// </summary>
            Warn,

            /// <summary>
            /// Error, this is something which has to be highlighted
            /// </summary>
            Err, 

            /// <summary>
            /// Not specified, no level is provided
            /// </summary>
            None
        }


        /// <summary>
        /// Constructs the instance
        /// </summary>
        public AnnotationInfoItem()
        {
            InformationType = InformationLevel.None;
        }

        /// <summary>
        /// Name of the analyzer, which created this item
        /// </summary>
        public string AnalyzerName { get; set; }

        /// <summary>
        /// Analyzer version, format is same, as for the assembly
        /// </summary>
        public Version AnalyzerVersion { get; set; }

        /// <summary>
        /// Analyzer condition, which was used to match this report
        /// </summary>
        public string AnalyzerCondition { get; set; }

        /// <summary>
        /// Type of information provided
        /// </summary>
        public InformationLevel InformationType { get; set; }

        /// <summary>
        /// Textual representation of the information
        /// </summary>
        public string Text { get; set; }


        /// <summary>
        /// Prints object in string format
        /// </summary>
        /// <returns>Textual representation of the Annotation info</returns>
        public override string ToString()
        {
            return $"Analyzer: {AnalyzerName}, AnalyzerVersion: {AnalyzerVersion}, InformationLevel: {InformationType}, Condition: {AnalyzerCondition}, Report: {Text}";
        }
    }
}
