﻿using Janus.Core.Exporters;
using Janus.Core.Importers;
using Janus.Core.Interfaces;
using Janus.Core.Models;
using Janus.Core.Models.Results;
using System;
using System.Collections.Generic;
using System.Linq;

namespace Janus
{
    /// <summary>
    /// This is the program for testing purposes
    /// It can easily be connected to the all projects
    /// </summary>
    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine("HELLO JANUS!");

            DependencyItem itemA = new DependencyItem() { Id="A", Version = "1.0.0"};
            itemA.License = "MIT";
            DependencyItem itemB = new DependencyItem() { Id="B", Version = "1.0.0" };
            itemB.License = "Apache2.0";
            DependencyItem itemC = new DependencyItem() { Id="C", Version = "1.0.0" };
            itemC.License = "GPL2";
            DependencyItem itemD = new DependencyItem() { Id="D", Version = "1.0.0" };
            DependencyItem itemE = new DependencyItem() { Id="E", Version = "1.0.0" };

            itemA.AnnotationInfo.Add(new AnnotationInfoItem() { 
                AnalyzerCondition = "==MIT",
                AnalyzerName = "LicenseAnalyzer",
                AnalyzerVersion = new Version(1, 0, 1),
                InformationType = AnnotationInfoItem.InformationLevel.Warn,
                Text = "Found match!"
            });

            itemB.AnnotationInfo.Add(new AnnotationInfoItem()
            {
                AnalyzerCondition = "==MIT",
                AnalyzerName = "LicenseAnalyzer",
                AnalyzerVersion = new Version(1, 0, 1),
                InformationType = AnnotationInfoItem.InformationLevel.Err,
                Text = "Found match!"
            });

            itemA.Dependencies.Add(new DependencyEdge() { Parent = itemA, Link = itemB });
            itemA.Dependencies.Add(new DependencyEdge() { Parent = itemA, Link = itemC });
            itemC.Dependencies.Add(new DependencyEdge() { Parent = itemC, Link = itemE });
            itemB.Dependencies.Add(new DependencyEdge() { Parent = itemB, Link = itemD });
            itemB.Dependencies.Add(new DependencyEdge() { Parent = itemB, Link = itemC });



            ProjectItem projectA = new ProjectItem();

            projectA.Name = "Dummy project 1";
            projectA.Path = "asd";
            projectA.LanguageVersion = "7";
            projectA.Language = "C#";
            projectA.Dependencies.Add(new DependencyEdge() { Link = itemA });

            ProjectItem projectB = new ProjectItem();

            projectB.Name = "Dummy project 2";
            projectB.Path = "asd";
            projectB.LanguageVersion = "7";
            projectB.Language = "C#";
            projectB.Dependencies.Add(new DependencyEdge() { Link = itemB });

            IList<ProjectItem> projects = new List<ProjectItem>();
            for (int i = 0; i < 1; i++)
            {
                projects.Add(projectA);
            }

            SolutionItem solution = new SolutionItem();
            solution.Name = "Full solution";
            solution.Projects.Add(new ProjectEdge() { Link = projectA });
            solution.Projects.Add(new ProjectEdge() { Link = projectB });

            IList<SolutionItem> solutions = new List<SolutionItem>();
            solutions.Add(solution);
            

            //List<DependencyItem> deps = new List<DependencyItem>();
            //deps.Add(itemA);
            DotExporter dotExp = DotExporter.Instance;
            //ExportResult dotResult = dotExp.ExportData(deps);
            ExportResult dotResult = dotExp.ExportData(solutions);

            Console.WriteLine(dotResult.ExportData);

            Console.WriteLine("SERIALIZE!");
            IExporter exporter = JsonExporter.Instance;
            ExportResult exportResult = exporter.ExportData(projects, "jsonoutput.json");
            Console.WriteLine(exportResult.ExportData);

            Console.WriteLine("DESERIALIZE!");
            IImporter importer = JsonImporter.Instance;
            ImportResult<DataSerializationWrapper> importWrapperResult = importer.ImportWrapperFromString(exportResult.ExportData);


            if (importWrapperResult.Result.DataType == null)
            {
                //NULL!!!!
                Console.WriteLine("NULL DATATYPE LOADED!");

            }
            else if (importWrapperResult.Result.DataType == new List<DependencyItem>().GetType().ToString())
            {
                ImportResult<IList<DependencyItem>> importedData = importer.ImportData<IList<DependencyItem>>(importWrapperResult.Result);
                foreach (var item in importedData.Result)
                {
                    Console.WriteLine(item.PrintPretty("", true));
                }
            }
            else if (importWrapperResult.Result.DataType == new List<ProjectItem>().GetType().ToString())
            {
                ImportResult<IList<ProjectItem>> importedData = importer.ImportData<IList<ProjectItem>>(importWrapperResult.Result);
                string result = TextExporter.Instance.ExportData(importedData.Result).ExportData;
                result += "";
                /*foreach (var item in importedData.Result)
                {
                    Console.WriteLine(item.PrintPretty("", true));
                }*/
            }
            else if (importWrapperResult.Result.DataType == new List<SolutionItem>().GetType().ToString())
            {
                ImportResult<IList<SolutionItem>> importedData = importer.ImportData<IList<SolutionItem>>(importWrapperResult.Result);
                foreach (var item in importedData.Result)
                {
                    Console.WriteLine(item.PrintPretty("", true));
                }
            }
            else
            {
                //Unknown ...
                Console.WriteLine("UNKNOWN DATATYPE LOADED!");
            }
        }
    }
}
