﻿using CommandLine;
using Janus.Core.Utils;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Janus.Parsers.DotnetCoreNuget
{
    /// <summary>
    /// Command line options for the tool
    /// 
    /// Extends the basic options provided by the core
    /// </summary>
    public class CLIOptions : CLIOptionsCoreBase
    {
        /// <summary>
        /// Path to the project files, list
        /// </summary>
        [Option('f', "projectFiles", 
            HelpText = "Input project files to be processed. (*.csproj or *.sln)")]
        public IEnumerable<string> InputFiles { get; set; }

        /// <summary>
        /// Specific dependencies, list
        /// </summary>
        [Option("analyzeDependencies",
            HelpText = "List of dependencies to be analyzed (\"<id>;<version>\") This option disables input files option values, framework version has to be specified!")]
        public IEnumerable<string> InputDependencies { get; set; }

        /// <summary>
        /// Framework version, tighted with custom dependencies
        /// </summary>
        [Option("frameworkVersion",
          Default = null,
          HelpText = "For custom dependency input, the framework version must be specified! (Example: \"net5.0\", \"netstandard2.1\", etc)")]
        public string FrameworkVersion { get; set; }

        /// <summary>
        /// Search depth
        /// </summary>
        [Option('d', "depth",
          Default = -1,
          HelpText = "Depth of the search in the dependency tree (Possible value: 1 - n), -1 is maximum.")]
        public int SearchDepth { get; set; }

        /// <summary>
        /// URL to the repository
        /// </summary>
        [Option('r', "repositoryUrl",
          Default = "https://api.nuget.org/v3/index.json",
          HelpText = "Nuget v3 repository URL")]
        public string RepositoryURL { get; set; }


    }
}
