using Janus.Core.Interfaces;
using Janus.Core.Models;
using Janus.Core.Models.Results;
using Moq;
using System;
using System.Collections.Generic;
using Xunit;

namespace Janus.Tests.Analyzers
{
    public class BasicTests
    {
        #region TestsToPass

        [Fact]
        public void OperationSuccessfulTrue()
        {
            var dependenciesToAnalyze = new DependencyItem();
            var myAnalyzer = new Mock<IAnalyzer>();
            myAnalyzer.Setup(
                x => x.AnalyzeDependencies(dependenciesToAnalyze))
                .Returns(new AnalysisResult() { OperationSuccessful = true }
                );

            AnalysisResult result = myAnalyzer.Object.AnalyzeDependencies(dependenciesToAnalyze);
            Assert.True(result.OperationSuccessful);
        }

        [Fact]
        public void AnalysisWithResult()
        {
            var dependenciesToAnalyze = new DependencyItem();
            string resultTextTest = "Matching depdendencies 2";

            var myAnalyzer = new Mock<IAnalyzer>();
            myAnalyzer.Setup(
                x => x.AnalyzeDependencies(dependenciesToAnalyze))
                .Returns(new AnalysisResult() { OperationSuccessful = true, 
                                                ResultText = resultTextTest
                                                }
                );

            AnalysisResult result = myAnalyzer.Object.AnalyzeDependencies(dependenciesToAnalyze);
            Assert.True(result.OperationSuccessful);
            Assert.Equal(resultTextTest, result.ResultText);
        }

        [Fact]
        public void AnalysisWithResultAndDependencies()
        {
            var problematic1 = new DependencyItem() { Id = "Problematic1"};
            var problematic2 = new DependencyItem() { Id = "Problematic2"};
            var dependenciesToAnalyze = new DependencyItem();
            string resultTextTest = "Matching depdendencies 2";

            var myAnalyzer = new Mock<IAnalyzer>();
            myAnalyzer.Setup(
                x => x.AnalyzeDependencies(dependenciesToAnalyze))
                .Returns(new AnalysisResult()
                {
                    OperationSuccessful = true,
                    ResultText = resultTextTest
                }
                );

            AnalysisResult result = myAnalyzer.Object.AnalyzeDependencies(dependenciesToAnalyze);
            Assert.True(result.OperationSuccessful);
            Assert.Equal(resultTextTest, result.ResultText);
        }

        #endregion

        #region TestsToFail

        [Fact]
        public void OperationSuccessfulFalse()
        {
            var dependenciesToAnalyze = new DependencyItem();
            var myAnalyzer = new Mock<IAnalyzer>();
            myAnalyzer.Setup(
                x => x.AnalyzeDependencies(dependenciesToAnalyze))
                .Returns(new AnalysisResult() { OperationSuccessful = false }
                );

            AnalysisResult result = myAnalyzer.Object.AnalyzeDependencies(dependenciesToAnalyze);
            Assert.False(result.OperationSuccessful);
        }

        #endregion
    }
}
